@@ -119,6 +119,7 @@ struct _GirlData {
 	gchar *selected_program_description;
 	GirlRunnersInfo *selected_runners;
 	gint timeout_id;
+	gint current_station_number;
 	GirlStationInfo *previous_station;
 	GirlStationInfo *selected_station;
 	gchar *selected_station_uri;
@@ -146,6 +147,8 @@ struct _GirlData {
 	GSubprocessLauncher *record_launcher;
 	gint record_status;
 	GPid record_pid;
+	gint station_count;
+	gint stream_count;
 };
 
 typedef struct _GirlData GirlData;
@@ -159,4 +162,13 @@ extern GList *girl_programs;
 extern GList *girl_stations;
 extern GList *girl_streams;
 
+extern gchar *list_item_data_key;
+
+static void  sigh_print_selection( GtkWidget *gtklist,
+				   gpointer   func_data);
+
+static void  sigh_button_event( GtkWidget      *gtklist,
+				GdkEventButton *event,
+				GtkWidget      *frame );
+
 #endif /* GIRL_H */
